@@ -1,7 +1,7 @@
 from .models.model_builder import ModelBuilder
 from .callbacks.callback import Callback
 from .callbacks.ckpt_callback import CkptCallback
-from .callbacks.wechat_send_msg_callback import WechatCallback
+from .events.wechat_receiver import WechatReceiver
 from .callbacks.reduce_lr_on_plateau import ReduceLROnPlateau
 from .models.base_model import BaseModel
 from .utils.config import init_cfg, load_cfg, merge_cfg
@@ -16,5 +16,10 @@ from .utils import logger
 from .events.event import Event
 from .events.event_center import EventCenter
 from .events.receiver import Receiver
+from .events.pbar_receiver import PBar
+from .events.tensorboard_receiver import TensorBoardReceiver
+from .models.trainable import Trainable
+from .models.group_model import GroupModel
+from .utils.global_data import set_global, get_global
 
 name = "torchelper"
\ No newline at end of file
