@@ -4,8 +4,8 @@ import torch
 from torch import nn
 from torch.nn import functional as F
 
-from torch_helper.ops.fused_act import FusedLeakyReLU, fused_leaky_relu
-from torch_helper.ops.upfirdn2d import upfirdn2d
+from torchelper.ops.fused_act import FusedLeakyReLU, fused_leaky_relu
+from torchelper.ops.upfirdn2d import upfirdn2d
 
 
 class NormStyleCode(nn.Module):
