@@ -3,8 +3,9 @@ class Event:
     Scalar="evt_scalar"
     Voice="evt_voice"
     Pic="evt_pic"
-    Level_loss = 0
-    Level_metric = 1
+    Level_step = 0
+    Level_epoch = 1
+    Level_val = 2
  
 
     def __init__(self, evt_type:str, data:dict, level:int=0, extra:dict={}):
