@@ -10,14 +10,22 @@ class EventCenter:
         pass
     
     @staticmethod
-    def register(evt_type:str, rcver:Receiver):
+    def register(evt_type, rcver:Receiver):
+        '''
+        evt_type: str|list
+        '''
         lock.acquire()
         global __event_map__
-        rcvers = __event_map__.get(evt_type, set())
-        rcvers.add(rcver)
-        __event_map__[evt_type] = rcvers
+        if isinstance(evt_type, str):
+            evt_type = [evt_type]
+        for evt in evt_type:
+            rcvers = __event_map__.get(evt, set())
+            rcvers.add(rcver)
+            __event_map__[evt] = rcvers
         lock.release()
 
+ 
+
     @staticmethod
     def __on_event(event:Event):
         lock.acquire()
